"PeriodicTS_ts"Class "PeriodicTS_ts" is a periodic class holding
"ts" objects.
Objects can be created by calls of the form new("PeriodicTS_zooreg", ...).
Objects can be created by calls of the form new("PeriodicTS_ts", x, ...).
.Data:Object of class "vector" ~~
cycle:Object of class "BasicCycle" ~~
tsp:Object of class "numeric" ~~
.S3Class:Object of class "character" ~~
pcstart:Object of class "ANY" ~~
Class "PeriodicTimeSeries", directly.
Class "ts", directly.
Class "Cyclic", by class "PeriodicTimeSeries", distance 2.
Class "structure", by class "ts", distance 2.
Class "oldClass", by class "ts", distance 2.
Class "vector", by class "ts", distance 3, with explicit coerce.
signature(from = "ts", to = "PeriodicTS_ts"): ...
signature(.Object = "PeriodicTS_ts"): ...