Each column is a quarterly time series. The time series start and end
at different times, so NA's are used to align them in a single
multivariate time series. Detailed account of the sources of the data
is given by
@@FransesB1; Data Appendix, p. 214;textualpcts.
year
(column 1)
The time formatted as yyyy.Q, where yyyy is the year
and Q is the quarter (one of 1, 2, 3 or 4.). This column
was part of the original data but is not really needed here since
the time series object contains the time information.
USTotalIPI
(column 2)
Total Industrial Production Index for the United States (1985 =
100), 1960.1--1991.4.
CanadaUnemployment
(column 3)
Unemployment in Canada, measured in 1000 persons, 1960.1 - 1987.4.
GermanyGNP
(column 4)
Real GNP in Germany, 1960.1 - 1990.4 .
UKTotalInvestment
(column 5)
Real Total Investment in the United Kindom, 1955.1 - 1988.4.
SA_USTotalIPI
(column 6)
Seasonally adjusted USTotalIPI.
SA_CanadaUnemployment
(column 7)
Seasonally adjusted CanadaUnemployment.
SA_GermanyGNP
(column 8)
Seasonally adjusted GermanyGNP.
UKGDP
(column 9)
United Kingdom gross domestic product (at 1985 prices),
1955.1--1988.4.
UKTotalConsumption
(column 10)
United Kingdom total consumption (at 1985 prices),
1955.1--1988.4.
UKNondurablesConsumption
(column 11)
United Kindom nondurables consumption (at 1985 prices), 1955.1--1988.4.
UKExport
(column 12)
United Kindom exports of goods and services (at 1985 prices),
1955.1--1988.4.
UKImport
(column 13)
United Kindom imports of goods and services (at 1985 prices),
1955.1--1988.4.
UKPublicInvestment
(column 14)
United Kindom public investment (at 1985 prices), 1962.1--1988.4.
UKWorkforce
(column 15)
United Kindom workforce (consisting of workforce in employment and
unemployment), 1955.1--1988.4.
SwedenNondurablesConsumption
(column 16)
Real per capita non-durables consumption in Sweden (measured in
logs), 1963.1--1988.1.
SwedenDisposableIncome
(column 17)
Real per capita disposable income in Sweden (measured in logs),
1963.1--1988.1.
SA_SwedenNondurablesConsumption
(column 18)
Seasonally adjusted SwedenNondurablesConsumption with
Census X-11 method, 1964.1--1988.1. (Using the approximate linear
Census X-11 filter given in Table 4.1, p. 52 in
FransesB1;textualpcts and generating the forecasts
and backcasts as described in Ooms (1994)).
SA_SwedenDisposableIncome
(column 19)
Seasonally adjusted SwedenDisposableIncome with Census X-11
method, 1964.1--1988.1. (Using the same method as above.)
More details on the individual time series are given by
FransesB1;textualpcts.