Learn R Programming

pcts (version 0.15.8)

pcacf_pwn_var: Variances of sample periodic autocorrelations

Description

Computes the variances of sample periodic autocorrelations from periodic white noise.

Usage

pcacf_pwn_var(nepoch, period, lag, season)

Value

A matrix whose (i,j)th entry contains the variance of the autocorrelation coefficient for season season[i] and lag lag[j].

Arguments

lag

desired lags, a vector of positive integers.

season

desired seasons.

nepoch

number of epochs.

period

number of seasons.

Author

Georgi N. Boshnakov

Details

These are given by McLeod (1994), see the reference, eq. (4.3).

References

McLeod1994diagnosticpcts

Examples

Run this code
pcacf_pwn_var(79, 12, 0:16, 1:12)

Run the code above in your browser using DataLab