Learn R Programming

pcts (version 0.15.8)

periodic_acf1_test: McLeod's test for periodic autocorrelation

Description

Performs McLeod's test for periodic autocorrelation.

Usage

periodic_acf1_test(acf, nepochs)

Value

A list containing the following components:

statistic

the value of the test statistic.

pvalue

the p-value associated with the test statistic.

Arguments

acf

sample periodic autocorrelation function

nepochs

the number of epochs used to get the acf

Author

Georgi N. Boshnakov

Details

The test statistic is a scaled sum of squares of lag 1 sample periodic autocorrelation coefficients, see McLeod (1993), eq. (5). The distribution is approximately chi-square under the null hypothesis of no periodic autocorrelation.

References

Mcleod1993parsimonypcts

McLeod1994diagnosticpcts

McLeod1995diagnosticCorrectionpcts