Learn R Programming

pcts (version 0.15.8)

meanvarcheck: Asymptotic covariance matrix of periodic mean

Description

Asymptotic covariance matrix of periodic mean.

Usage

meanvarcheck(parmodel, n)

meancovmat(parmodel, n, cor = FALSE, result = "var")

Value

if result = "var" a matrix, otherwise a vector

Arguments

parmodel

a periodic model.

n

number of observations (TODO: need clarification here).

cor

if TRUE, return correlations

result

if "var", return the diagonal of the covariance matrix, otherwise return the matrix.

Author

Georgi N. Boshnakov

Details

Computes asymptotic covariance or correlation matrix of the periodic means.

See Also

parcovmatlist

Examples

Run this code
x <- arima.sim(list(ar=0.9), n=1000)
proba1 <- fitPM(c(3,2,2,2), x)

meancovmat(proba1, 100)
meancovmat(proba1, 100, cor = TRUE)
meancovmat(proba1, 100, result = "")
meancovmat(proba1, 100, cor = TRUE, result = "")

meanvarcheck(proba1, 100)

Run the code above in your browser using DataLab