pcAr.ss: Compute the sum of squares for a given PAR model
Description
Compute the sum of squares for a given PAR model.
Usage
pcAr.ss(x, model, eps = numeric(length(x)))
Arguments
- x
time series, a numeric vector.
- model
a model.
- eps
residuals, defaults to a vector of zeroes. This may be used
for models with moving average terms, for example.
Author
Georgi N. Boshnakov