powered by
Computes the variances of sample periodic autocorrelations from periodic white noise.
pcacf_pwn_var(nepoch, period, lag, season)
A matrix whose (i,j)th entry contains the variance of the autocorrelation coefficient for season season[i] and lag lag[j].
season[i]
lag[j]
desired lags, a vector of positive integers.
desired seasons.
number of epochs.
number of seasons.
Georgi N. Boshnakov
These are given by McLeod (1994), see the reference, eq. (4.3).
McLeod1994diagnosticpcts
pcacf_pwn_var(79, 12, 0:16, 1:12)
Run the code above in your browser using DataLab