Performs McLeod's test for periodic autocorrelation.
periodic_acf1_test(acf, nepochs)A list containing the following components:
the value of the test statistic.
the p-value associated with the test statistic.
sample periodic autocorrelation function
the number of epochs used to get the acf
Georgi N. Boshnakov
The test statistic is a scaled sum of squares of lag 1 sample periodic autocorrelation coefficients, see McLeod (1993), eq. (5). The distribution is approximately chi-square under the null hypothesis of no periodic autocorrelation.
Mcleod1993parsimonypcts
McLeod1994diagnosticpcts
McLeod1995diagnosticCorrectionpcts